diff src/drawline.c @ 30693:a59a8ce13129 v9.0.0681

patch 9.0.0681: "<<<" shows for 'smoothscroll' even when 'showbreak is set Commit: https://github.com/vim/vim/commit/0937b9fb244949b7ce9bfcf8398d7495b9b6aa85 Author: Bram Moolenaar <Bram@vim.org> Date: Thu Oct 6 21:24:34 2022 +0100 patch 9.0.0681: "<<<" shows for 'smoothscroll' even when 'showbreak is set Problem: "<<<" shows for 'smoothscroll' even when 'showbreak is set. Solution: When 'showbreak' is set do not display "<<<".
author Bram Moolenaar <Bram@vim.org>
date Thu, 06 Oct 2022 22:30:03 +0200
parents 024e1c1da31f
children e1fbb6571b58
line wrap: on
line diff
--- a/src/drawline.c
+++ b/src/drawline.c
@@ -745,12 +745,17 @@ text_prop_position(
 
 /*
  * Call screen_line() using values from "wlv".
  * Also takes care of putting "<<<" on the first line for 'smoothscroll'.
  */
     static void
 wlv_screen_line(win_T *wp, winlinevars_T *wlv, int negative_width)
 {
-    if (wlv->row == 0 && wp->w_skipcol > 0)
+    if (wlv->row == 0 && wp->w_skipcol > 0
+#if defined(FEAT_LINEBREAK)
+	    && *get_showbreak_value(wp) == NUL
+#endif
+	    )
     {
 	int off = (int)(current_ScreenLine - ScreenLines);
@@ -745,12 +745,17 @@ text_prop_position(
 /*
  * Call screen_line() using values from "wlv".
- * Also takes care of putting "<<<" on the first line for 'smoothscroll'.
+ * Also takes care of putting "<<<" on the first line for 'smoothscroll'
+ * when 'showbreak' is not set.
  */
     static void